Skip to contents

Exact radius search for bigmemory::big.matrix

Usage

radius_bigmatrix(
  x,
  query = NULL,
  radius,
  metric = "euclidean",
  block_size = knn_default_block_size(),
  plan = NULL,
  exclude_self = is.null(query),
  sort = TRUE
)

Arguments

x

A bigmemory::big.matrix, an external pointer referencing a big.matrix, or a prepared reference returned by knn_prepare_bigmatrix().

query

Optional query source. Supply NULL for self-search, another big.matrix or external pointer for streamed queries, or a dense numeric matrix.

radius

Distance threshold for including a neighbour.

metric

Distance metric. Supported values are "euclidean", "sqeuclidean", and "cosine".

block_size

Number of rows to process per query and reference block.

plan

Optional execution plan returned by knn_plan_bigmatrix().

exclude_self

Logical flag controlling whether a query row may return itself as a neighbour when query references the same matrix as x.

sort

Logical flag controlling whether each query's matches are sorted by distance and then by index.

Value

A list with components index, distance, offset, n_match, radius, metric, n_ref, n_query, exact, and backend.