Stream exact radius-search results into destination big.matrix objects with checkpoints
Source: R/v3_interface.R
radius_stream_job_bigmatrix.RdStream exact radius-search results into destination big.matrix objects with checkpoints
Usage
radius_stream_job_bigmatrix(
x,
query = NULL,
xpIndex,
xpDistance = NULL,
xpOffset,
radius,
metric = "euclidean",
plan = NULL,
block_size = knn_default_block_size(),
exclude_self = is.null(query),
sort = TRUE,
checkpoint_path = NULL
)Arguments
- x
A
bigmemory::big.matrixor prepared reference with a stored descriptor.- query
Optional query source. Supply
NULLfor self-search, anotherbig.matrix, or a dense/sparse matrix.- xpIndex
A writable single-column
bigmemory::big.matrixthat receives flattened 1-based neighbour indices.- xpDistance
Optional writable single-column
bigmemory::big.matrixthat receives flattened neighbour distances.- xpOffset
A writable single-column
bigmemory::big.matrixthat receives 1-based offsets into the flattened output vectors.- radius
Distance threshold for including a neighbour.
- metric
Distance metric. Supported values are
"euclidean","sqeuclidean", and"cosine".- plan
Optional execution plan returned by
knn_plan_bigmatrix().- block_size
Number of query rows to process per block.
- exclude_self
Logical flag controlling whether self matches are removed when
queryreferences the same source asx.- sort
Logical flag controlling whether each query's matches are sorted by distance and then by index.
- checkpoint_path
Optional path for a resumable job checkpoint.